@@ -41,6 +41,7 @@
 #ifdef GDK_RENDERING_VULKAN
 const GdkDebugKey gdk_vulkan_feature_keys[] = {
   { "dual-source-blend", GDK_VULKAN_FEATURE_DUAL_SOURCE_BLEND, "Disable dual source blending" },
+  { "profile", GDK_VULKAN_FEATURE_PROFILE, "Disable profiling support" },
   { "dmabuf", GDK_VULKAN_FEATURE_DMABUF, "Never import Dmabufs" },
   { "win32", GDK_VULKAN_FEATURE_WIN32, "Never import Windows resources" },
   { "ycbcr", GDK_VULKAN_FEATURE_YCBCR, "Do not support Ycbcr textures (also disables dmabufs)" },
@@ -295,6 +296,10 @@ gdk_vulkan_strerror (VkResult result)
     case VK_ERROR_NOT_ENOUGH_SPACE_KHR:
       return "The application did not provide enough space to return all the required data. (VK_ERROR_NOT_ENOUGH_SPACE_KHR)";
 #endif
+#if VK_HEADER_VERSION >= 335
+    case VK_ERROR_PRESENT_TIMING_QUEUE_FULL_EXT:
+      return "The swapchain's internal timing queue is full. (VK_ERROR_PRESENT_TIMING_QUEUE_FULL_EXT)";
+#endif
 
     case VK_RESULT_MAX_ENUM:
     default:
@@ -640,6 +645,9 @@ physical_device_check_features (VkPhysicalDevice device)
   if (v10_features.features.dualSrcBlend)
     features |= GDK_VULKAN_FEATURE_DUAL_SOURCE_BLEND;
 
+  if (v10_features.features.pipelineStatisticsQuery)
+    features |= GDK_VULKAN_FEATURE_PROFILE;
+
   if (ycbcr_features.samplerYcbcrConversion ||
       physical_device_supports_extension (device, VK_KHR_SAMPLER_YCBCR_CONVERSION_EXTENSION_NAME))
     features |= GDK_VULKAN_FEATURE_YCBCR;
@@ -1865,6 +1873,7 @@ gdk_display_create_vulkan_device (GdkDisplay  *display,
                                                     .ppEnabledExtensionNames = (const char * const *) device_extensions->pdata,
                                                     .pEnabledFeatures = &(VkPhysicalDeviceFeatures) {
                                                         .dualSrcBlend = ENABLE_IF (GDK_VULKAN_FEATURE_DUAL_SOURCE_BLEND),
+                                                        .pipelineStatisticsQuery = ENABLE_IF (GDK_VULKAN_FEATURE_PROFILE),
                                                     },
                                                     .pNext = &(VkPhysicalDeviceVulkan11Features) {
                                                         .sType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_VULKAN_1_1_FEATURES,
